@@ -20,3 +20,7 @@
 #'
 #' @keywords internal
 "_PACKAGE"
+
+## usethis namespace: start
+## usethis namespace: end
+NULL
